The hardware and bandwidth for this mirror is donated by dogado GmbH, the Webhosting and Full Service-Cloud Provider. Check out our Wordpress Tutorial.
If you wish to report a bug, or if you are interested in having us mirror your free-software or open-source project, please feel free to contact us at mirror[@]dogado.de.

Package {mlr3verse}


Title: Easily Install and Load the 'mlr3' Package Family
Version: 0.3.2
Description: The 'mlr3' package family is a set of packages for machine-learning purposes built in a modular fashion. This wrapper package is aimed to simplify the installation and loading of the core 'mlr3' packages. Get more information about the 'mlr3' project at https://mlr3book.mlr-org.com/.
License: LGPL-3
URL: https://mlr3verse.mlr-org.com, https://github.com/mlr-org/mlr3verse
BugReports: https://github.com/mlr-org/mlr3verse/issues
Depends: mlr3 (≥ 0.20.0), R (≥ 3.1.0)
Imports: bbotk (≥ 1.5.0), data.table, mlr3cluster (≥ 0.1.10), mlr3data (≥ 0.9.0), mlr3filters (≥ 0.8.1), mlr3fselect (≥ 1.2.1), mlr3hyperband (≥ 0.6.0), mlr3inferr (≥ 0.1.0), mlr3learners (≥ 0.9.0), mlr3mbo (≥ 0.2.8), mlr3misc (≥ 0.16.0), mlr3pipelines (≥ 0.7.1), mlr3tuning (≥ 1.3.0), mlr3tuningspaces (≥ 0.5.2), mlr3viz (≥ 0.10.0), paradox (≥ 1.0.1)
Suggests: miesmuschel, mlr3batchmark, mlr3benchmark, mlr3db, mlr3fairness, mlr3fda, mlr3oml, mlr3proba (≥ 0.7.4), mlr3spatial, mlr3spatiotempcv, mlr3summary, mlr3torch, rush
Additional_repositories: https://mlr-org.r-universe.dev
Encoding: UTF-8
Config/roxygen2/version: 8.0.0.9000
NeedsCompilation: no
Packaged: 2026-06-22 11:40:29 UTC; marc
Author: Michel Lang ORCID iD [aut], Patrick Schratz ORCID iD [aut], Marc Becker ORCID iD [cre, aut]
Maintainer: Marc Becker <marcbecker@posteo.de>
Repository: CRAN
Date/Publication: 2026-06-22 13:20:02 UTC

mlr3verse: Easily Install and Load the 'mlr3' Package Family

Description

The 'mlr3' package family is a set of packages for machine-learning purposes built in a modular fashion. This wrapper package is aimed to simplify the installation and loading of the core 'mlr3' packages. Get more information about the 'mlr3' project at https://mlr3book.mlr-org.com/.

Author(s)

Maintainer: Marc Becker marcbecker@posteo.de (ORCID)

Authors:

See Also

Useful links:


Print mlr3* package versions

Description

Returns the package versions of imported and suggested mlr3 packages as a data.table::data.table(). Suggested packages that are not installed are listed with version NA.

Usage

mlr3verse_info()

Examples

mlr3verse_info()

Objects exported from other packages

Description

These objects are imported from other packages. Follow the links below to see their documentation.

bbotk

mlr_terminators, trm(), trms()

data.table

as.data.table()

mlr3cluster

as_prediction_clust(), as_task_clust()

mlr3filters

flt(), flts(), mlr_filters

mlr3fselect

auto_fselector(), callback_batch_fselect(), ensemble_fselect(), extract_inner_fselect_archives(), extract_inner_fselect_results(), fs(), fselect(), fselect_nested(), fsi(), fss(), mlr_fselectors

mlr3hyperband

hyperband_budget(), hyperband_n_configs(), hyperband_schedule()

mlr3misc

clbk(), clbks(), mlr_callbacks

mlr3pipelines

%>>!%, %>>%, as_graph(), as_pipeop(), chain_graphs(), concat_graphs(), GraphLearner, gunion(), mlr_graphs, mlr_pipeops, po(), pos(), ppl(), selector_all(), selector_cardinality_greater_than(), selector_grep(), selector_intersect(), selector_invert(), selector_missing(), selector_name(), selector_none(), selector_setdiff(), selector_type(), selector_union()

mlr3tuning

auto_tuner(), callback_async_tuning(), callback_batch_tuning(), extract_inner_tuning_archives(), extract_inner_tuning_results(), mlr_tuners, ti(), ti_async(), tnr(), tnrs(), tune(), tune_nested()

mlr3tuningspaces

lts(), ltss(), mlr_tuning_spaces

mlr3viz

autoplot, fortify, plot_learner_prediction()

paradox

generate_design_grid(), generate_design_lhs(), generate_design_random(), p_dbl(), p_fct(), p_int(), p_lgl(), p_uty(), ps(), to_tune()

These binaries (installable software) and packages are in development.
They may not be fully stable and should be used with caution. We make no claims about them.
Health stats visible at Monitor.