| Title: | Easily Install and Load the 'mlr3' Package Family |
|---|---|
| Description: | The 'mlr3' package family is a set of packages for machine-learning purposes built in a modular fashion. This wrapper package is aimed to simplify the installation and loading of the core 'mlr3' packages. Get more information about the 'mlr3' project at <https://mlr3book.mlr-org.com/>. |
| Authors: | Michel Lang [aut] (ORCID: <https://orcid.org/0000-0001-9754-0393>), Patrick Schratz [aut] (ORCID: <https://orcid.org/0000-0003-0748-6624>), Marc Becker [cre, aut] (ORCID: <https://orcid.org/0000-0002-8115-0400>) |
| Maintainer: | Marc Becker <[email protected]> |
| License: | LGPL-3 |
| Version: | 0.3.1 |
| Built: | 2026-05-23 09:38:44 UTC |
| Source: | https://github.com/mlr-org/mlr3verse |
The 'mlr3' package family is a set of packages for machine-learning purposes built in a modular fashion. This wrapper package is aimed to simplify the installation and loading of the core 'mlr3' packages. Get more information about the 'mlr3' project at https://mlr3book.mlr-org.com/.
Maintainer: Marc Becker [email protected] (ORCID)
Authors:
Michel Lang [email protected] (ORCID)
Patrick Schratz [email protected] (ORCID)
Useful links:
Report bugs at https://github.com/mlr-org/mlr3verse/issues
Returns the package versions of imported and suggested mlr3 packages as a data.table::data.table().
Suggested packages that are not installed are listed with version NA.
mlr3verse_info()mlr3verse_info()
mlr3verse_info()mlr3verse_info()